@@ -10,8 +10,8 @@ __all__ = [
     "StatusNotFound",
     "InvalidOption",
     "CommandNotFound",
-    "ShowHelp",
     "GitException",
+    "GitHubException",
     "ConfigException",
     "ClickUpException",
 ]
@@ -53,14 +53,14 @@ class CommandNotFound(GenericException):
     "Command not found"
 
 
-class ShowHelp(GenericException):
-    "Show help message"
-
-
 class GitException(GenericException):
     "Git exception"
 
 
+class GitHubException(GenericException):
+    "GitHub exception"
+
+
 class ConfigException(GenericException):
     "Missing configuration exception"
 
